@@ -10,7 +10,7 @@ from pathlib import Path
 from collections import deque
 
 from yolov6.utils.downloads import attempt_download_from_hub, attempt_download
-from yolov6.utils.events import LOGGER, load_yaml
+from yolov6.utils.events import LOGGER
 from yolov6.layers.common import DetectBackend
 from yolov6.data.datasets import LoadData
 from yolov6.utils.nms import non_max_suppression
